==> blender-2.53-beta.tar.gz: blender-2.53-beta/intern/audaspace/intern/AUD_FileFactory.cpp <==
/*
 * $Id: AUD_FileFactory.cpp 28793 2010-05-16 19:41:49Z nazgul $
 *
 * ***** BEGIN LGPL LICENSE BLOCK *****
 *
 * Copyright 2009 Jörg Hermann Müller
 *
 * This file is part of AudaSpace.
 *
 * AudaSpace is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * AudaSpace is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with AudaSpace.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ***** END LGPL LICENSE BLOCK *****
 */

#include "AUD_FileFactory.h"
#include "AUD_Buffer.h"

#include <cstring>

#ifdef WITH_FFMPEG
// needed for INT64_C
#define __STDC_CONSTANT_MACROS

#include "AUD_FFMPEGReader.h"
#endif
#ifdef WITH_SNDFILE
#include "AUD_SndFileReader.h"
#endif

AUD_FileFactory::AUD_FileFactory(const char* filename)
{
	if(filename != NULL)
	{
		m_filename = new char[strlen(filename)+1]; AUD_NEW("string")
		strcpy(m_filename, filename);
	}
	else
		m_filename = NULL;
}

AUD_FileFactory::AUD_FileFactory(unsigned char* buffer, int size)
{
	m_filename = NULL;
	m_buffer = AUD_Reference<AUD_Buffer>(new AUD_Buffer(size));
	memcpy(m_buffer.get()->getBuffer(), buffer, size);
}

AUD_FileFactory::~AUD_FileFactory()
{
	if(m_filename)
	{
		delete[] m_filename; AUD_DELETE("string")
	}
}

AUD_IReader* AUD_FileFactory::createReader()
{
	AUD_IReader* reader = 0;

#ifdef WITH_SNDFILE
	try
	{
		if(m_filename)
			reader = new AUD_SndFileReader(m_filename);
		else
			reader = new AUD_SndFileReader(m_buffer);
		AUD_NEW("reader")
		return reader;
	}
	catch(AUD_Exception e) {}
#endif

#ifdef WITH_FFMPEG
	try
	{
		if(m_filename)
			reader = new AUD_FFMPEGReader(m_filename);
		else
			reader = new AUD_FFMPEGReader(m_buffer);
		AUD_NEW("reader")
		return reader;
	}
	catch(AUD_Exception e) {}
#endif

	return reader;
}

==> blender-2.55-beta.tar.gz: blender-2.55-beta/intern/audaspace/intern/AUD_FileFactory.cpp <==
/*
 * $Id: AUD_FileFactory.cpp 31382 2010-08-16 15:42:29Z nexyon $
 *
 * ***** BEGIN LGPL LICENSE BLOCK *****
 *
 * Copyright 2009 Jörg Hermann Müller
 *
 * This file is part of AudaSpace.
 *
 * AudaSpace is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * AudaSpace is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with AudaSpace.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ***** END LGPL LICENSE BLOCK *****
 */

#ifdef WITH_FFMPEG
// needed for INT64_C
#ifndef __STDC_CONSTANT_MACROS
#define __STDC_CONSTANT_MACROS
#endif
#include "AUD_FFMPEGReader.h"
#endif

#include "AUD_FileFactory.h"
#include "AUD_Buffer.h"

#include <cstring>

#ifdef WITH_SNDFILE
#include "AUD_SndFileReader.h"
#endif

AUD_FileFactory::AUD_FileFactory(std::string filename) :
	m_filename(filename)
{
}

AUD_FileFactory::AUD_FileFactory(const data_t* buffer, int size) :
	m_buffer(new AUD_Buffer(size))
{
	memcpy(m_buffer.get()->getBuffer(), buffer, size);
}

static const char* read_error = "AUD_FileFactory: File couldn't be read.";

AUD_IReader* AUD_FileFactory::createReader() const
{
#ifdef WITH_SNDFILE
	try
	{
		if(m_buffer.get())
			return new AUD_SndFileReader(m_buffer);
		else
			return new AUD_SndFileReader(m_filename);
	}
	catch(AUD_Exception&) {}
#endif

#ifdef WITH_FFMPEG
	try
	{
		if(m_buffer.get())
			return new AUD_FFMPEGReader(m_buffer);
		else
			return new AUD_FFMPEGReader(m_filename);
	}
	catch(AUD_Exception&) {}
#endif

	AUD_THROW(AUD_ERROR_FILE, read_error);
}
